@@ -1,20 +1,3 @@
-"""Payton Shader
-
-Payton Shader is an OpenGL 3.3 Compatible GLSL (330) module. Basic principle
-is to be be able to compile vertex and fragment shaders and hold basic
-ready-to-use shaders.
-
-A usual user should not be aware of this shading system. Basic shaders defined
-should be enough for simple simulations. Our intention is not to create a
-graphics library. We want to create a simulation platform and let developers
-to focus on mathematics rather than OpenGL Stuff.
-
-Also, keep in mind that, this is NOT a generic-purpose shader class which can
-be used at common OpenGL apps. This shader class is just enough of what is
-essential to Payton Library. That is all.
-
-"""
-
 import ctypes
 import logging
 from typing import Any, Dict, List, Optional
@@ -105,6 +88,7 @@ uniform vec3 light_pos[100]; // assume 100 lights max.
 uniform vec3 light_color[100];
 uniform vec3 camera_pos;
 uniform bool shadow_enabled;
+uniform int samples;
 
 uniform int LIGHT_COUNT;
 
@@ -112,6 +96,7 @@ uniform vec3 object_color;
 uniform int material_mode;
 uniform float opacity;
 uniform float far_plane;
+uniform int lit;
 
 uniform sampler2D tex_unit;
 uniform samplerCube depthMap;
@@ -132,7 +117,6 @@ float ShadowCalculation(vec3 fragPos)
     float currentDepth = length(fragToLight);
     float shadow = 0.0;
     float bias = 0.15;
-    int samples = 20;
 
     float viewDistance = length(camera_pos - fragPos);
     float diskRadius = (1.0 + (viewDistance / far_plane)) / 25.0;
@@ -141,7 +125,7 @@ float ShadowCalculation(vec3 fragPos)
     {
         float closestDepth = texture(depthMap, fragToLight +
                                      gridSamplingDisk[i] * diskRadius).r;
-        closestDepth *= 100.0;
+        closestDepth *= far_plane;
         if(currentDepth - bias > closestDepth)
              shadow += 1.0;
     }
@@ -151,23 +135,25 @@ float ShadowCalculation(vec3 fragPos)
 
 void main()
 {
-    if (material_mode == 0) {
-        // lightless material with color
-        FragColor = vec4(object_color, opacity);
+    vec3 color;
+    float alpha;
+    if (material_mode == 0 || material_mode == 2) {
+        color = object_color;
+        alpha = opacity;
     }
-    if (material_mode == 1) {
-        // lightless material with texture
-        FragColor = texture(tex_unit, tex_coords);
+    if (material_mode == 1 || material_mode == 3) {
+        color = texture(tex_unit, tex_coords).rgb;
+        alpha = texture(tex_unit, tex_coords).a;
+    }
+    if (material_mode == 4) {
+        color = frag_color;
+        alpha = opacity;
     }
-    if (material_mode == 2 || material_mode == 3) {
-        vec3 color;
-        if (material_mode == 2) {
-            color = object_color;
-        } else {
-            color = texture(tex_unit, tex_coords).rgb;
-        }
-        vec3 norm = normalize(l_normal);
 
+    if (lit == 0) {
+        FragColor = vec4(color, alpha);
+    } else {
+        vec3 norm = normalize(l_normal);
         for (int i = 0; i < LIGHT_COUNT; i++) {
             vec3 ambient = 0.3 * light_color[i];
 
@@ -184,13 +170,10 @@ void main()
             float shadow = shadow_enabled ? ShadowCalculation(l_fragpos) : 0.0;
             vec3 lighting = (ambient + (1.0 - shadow) *
                              (diffuse + specular)) * color;
-            FragColor = vec4(lighting, opacity);
+
+            FragColor = vec4(lighting, alpha);
         }
     }
-    if (material_mode == 4) {
-        // Lightless per vertex color
-        FragColor = vec4(frag_color, opacity);
-    }
 }"""  # type: str
 
 
@@ -261,23 +244,6 @@ void main()
 
 
 class Shader(object):
-    """Payton shader class. Creates shaders / programs
-
-    For better performance, Shader aims to reduce the number of
-    `glGetUniformlocation` function calls. For this purpose, `__init__` and
-    `build` functions accept a list of variable names as `variables` argument.
-
-    If variable not found in `self.variables` then the system will try to
-    locate the variable location and store it in `self.variables` for
-    future reference.
-
-    This way, Shader goes through this list of variables after compiling the
-    shader program and stores their locations in memory for future use.
-
-    If you provide the list of variable names in build function call then
-    it will overwrite the existing list.
-    """
-
     NO_LIGHT_COLOR = 0  # type: int
     NO_LIGHT_TEXTURE = 1  # type: int
     LIGHT_COLOR = 2  # type: int
@@ -294,13 +260,6 @@ class Shader(object):
         variables: Optional[List[str]] = None,
         **kwargs: Any,
     ):
-        """Initialize Shader.
-
-        Args:
-          fragment: Fragment shader code
-          vertex: Vertex shader code
-          variables: List of in/out/uniform variable names.
-        """
         self.fragment_shader_source = fragment
         self.vertex_shader_source = vertex
         self.geometry_shader_source = geometry
@@ -313,41 +272,20 @@ class Shader(object):
         self.program: int = -1
 
     def build(self) -> int:
-        """Build GLSL Shader
-        Compile shaders and compile glsl program
-        Args:
-          variables: List of in/out/uniform variable names.
-        Return:
-            self.program
-        """
-        vertex_shader = shaders.compileShader(
-            self.vertex_shader_source, GL_VERTEX_SHADER
-        )
-        fragment_shader = shaders.compileShader(
-            self.fragment_shader_source, GL_FRAGMENT_SHADER
-        )
+        vertex_shader = shaders.compileShader(self.vertex_shader_source, GL_VERTEX_SHADER)
+        fragment_shader = shaders.compileShader(self.fragment_shader_source, GL_FRAGMENT_SHADER)
         geometry_shader = None
         if self.geometry_shader_source != "":
-            geometry_shader = shaders.compileShader(
-                self.geometry_shader_source, GL_GEOMETRY_SHADER
-            )
+            geometry_shader = shaders.compileShader(self.geometry_shader_source, GL_GEOMETRY_SHADER)
 
         if geometry_shader is not None:
-            self.program = shaders.compileProgram(
-                vertex_shader, fragment_shader, geometry_shader
-            )
+            self.program = shaders.compileProgram(vertex_shader, fragment_shader, geometry_shader)
         else:
-            self.program = shaders.compileProgram(
-                vertex_shader, fragment_shader
-            )
+            self.program = shaders.compileProgram(vertex_shader, fragment_shader)
 
         return self.program
 
     def use(self) -> bool:
-        """Use GLSL Program.
-        This method should be called before setting any variables or rendering
-        any entities
-        """
         if self.program == -1:
             logging.error("Shader not compiled")
             return False
@@ -356,40 +294,21 @@ class Shader(object):
         return True
 
     def end(self) -> None:
-        """Set the active GLSL program to 0
-        """
         glUseProgram(0)
         glDisable(GL_PROGRAM_POINT_SIZE)
 
-    def set_matrix4x4_np(
-        self, variable: str, value: np.ndarray, transpose: bool = False
-    ) -> bool:
-        """Set 4x4 Numpy matrix value
-
-        Some elements like Observer and Light can pass their matrices directly
-        as numpy array to reduce number of object conversions. This is the
-        ideal way if possible.
-
-        Args:
-          variable: Variable name to set
-          value: Matrix to set. (Numpy matrix)
-          transpose: Transpose matrix.
-        """
+    def set_matrix4x4_np(self, variable: str, value: np.ndarray, transpose: bool = False) -> bool:
         g_transpose = GL_TRUE if transpose else GL_FALSE
         location = self.get_location(variable)
         if location == -1:
             return False
 
         glUniformMatrix4fv(
-            location,
-            1,
-            g_transpose,
-            np.asfortranarray(value, dtype=np.float32),
+            location, 1, g_transpose, value,
         )
         return True
 
     def get_location(self, variable: str) -> int:
-        """Get location of a given variable within the shader"""
         if variable in self._stack:
             return self._stack[variable]
         location = glGetUniformLocation(self.program, variable)
@@ -397,25 +316,10 @@ class Shader(object):
         self._stack[variable] = location
         return location
 
-    def set_matrix4x4(
-        self, variable: str, value: List[List[float]], transpose: bool = False
-    ) -> None:
-        """Set 4x4 Matrix value
-
-        This method will simply convert `value` into numpy array and call
-        `payton.scene.shader.Shader.set_matrix4x4_np` method.
-
-        Args:
-          variable: Variable name to set
-          value: Matrix to set. (Numpy matrix)
-          transpose: Transpose matrix.
-        """
+    def set_matrix4x4(self, variable: str, value: List[List[float]], transpose: bool = False) -> None:
         self.set_matrix4x4_np(variable, np.array(value, np.float32), transpose)
 
-    def set_vector3_array_np(
-        self, variable: str, value: np.ndarray, count: int
-    ) -> bool:
-        """Set array of vec3 as numpy array value"""
+    def set_vector3_array_np(self, variable: str, value: np.ndarray, count: int) -> bool:
         value = value.flatten()
         location = self.get_location(variable)
         if location == -1:
@@ -424,16 +328,6 @@ class Shader(object):
         return True
 
     def set_vector3_np(self, variable: str, value: np.ndarray) -> bool:
-        """Set Vector 3 as numpy array value
-
-        Some elements like Light or pre-set materials can pass their
-        vertices directly as numpy array to reduce number of object
-        conversions.
-
-        Args:
-          variable: Variable name to set
-          value: Vector 3 to set. (Numpy array with 3 elemenets)
-        """
         location = self.get_location(variable)
         if location == -1:
             return False
@@ -441,15 +335,6 @@ class Shader(object):
         return True
 
     def set_vector4_np(self, variable: str, value: np.ndarray) -> bool:
-        """Set Vector 4 as numpy array value
-
-        Some elements like Light or pre-set materials can pass their vertices
-        directly as numpy array to reduce number of object conversions.
-
-        Args:
-          variable: Variable name to set
-          value: Vector 4 to set. (Numpy array with 4 elemenets)
-        """
         location = self.get_location(variable)
         if location == -1:
             return False
@@ -457,24 +342,9 @@ class Shader(object):
         return True
 
     def set_vector3(self, variable: str, value: List[float]) -> None:
-        """Set Vector 3 as array value
-
-        This method will simply convert `value` into numpy array and call
-        `payton.scene.shader.Shader.set_vector3_np` method.
-
-        Args:
-          variable: Variable name to set
-          value: Vector 3 to set. (Numpy array with 3 elemenets)
-        """
         self.set_vector3_np(variable, np.array(value, dtype=np.float32))
 
     def set_int(self, variable: str, value: int) -> bool:
-        """Set Integer value
-
-        Args:
-          variable: Variable name to set
-          value: Integer value to set
-        """
         location = self.get_location(variable)
         if location == -1:
             return False
@@ -483,12 +353,6 @@ class Shader(object):
         return True
 
     def set_float(self, variable: str, value: float) -> bool:
-        """Set Float value
-
-        Args:
-          variable: Variable name to set
-          value: Floaf value to set
-        """
         location = self.get_location(variable)
         if location == -1:
             return False
